#include <inttypes.h>
#include <avr/io.h>
#include <util/delay.h>
#include <avr/interrupt.h>

//connect the S1/S2 outputs of Cerebot to DIR1/EN1 inputs of HB2 module
//then S3/S4 outputs of Cerebot to DIR2/EN2 inputs of HB2 module
//connect power (from servo heads outputs on Cerebot) to HB2 module (GND/VCC)
//connect BlueSmirf to Tx1/Rx1 and to power from the same connector (JE)

// this program will print menu on terminal (connect through BlueTooth module)
// which allows to steer the robot forward, backward, spin left, right, and stop
// it also allows to set the speed of motors
// it controls the motors directly in the main loop, not yet using the timers

#include <stdio.h>
#include "console.h"

#include "motor.h"

//this function sleeps s deciseconds (if F_CPU is set to frequency of processor)
void dsleep(uint8_t s)
{
  uint8_t i;
  while (s--) for (i = 0; i < 10; i++) _delay_ms(10);
}

//this function from uart2.c checks if there is a new character on serial port
int uart1GetByte(void);

int menu(int power)
{
	int menu;
	
    printf("\nNidarbot controller\n\n");
    printf(" 1) forward\n");
    printf(" 2) backward\n");
    printf(" 3) spin left\n");
	printf(" 4) spin right\n");
    printf(" 5) set power (%d)\n", power);
	printf(" 6) exit\n");
    scanf("%d", &menu);
	return menu;
}

int main(void)
{
  int op, n;
  register uint16_t i;
  register uint8_t j;
  register uint8_t wait1;
  register uint8_t wait2;
  
  // show that the program started (LED0)
  DDRE = 0xFF;
  PORTE = PINE | 16;

  console1_init(2400, PARITY_ODD);

  motor1_init();
  motor2_init();
  
  wait1 = 10;
  wait2 = 10;
  n = 10;

  do {
    op = menu(n);
	
    switch (op)
    {
  	  case 1: motor1_clockwise();
			  motor2_clockwise();
			  break;
	  case 2: motor1_counterclockwise();
	          motor2_counterclockwise();
			  break;
	  case 3: motor1_counterclockwise();
			  motor2_clockwise();
			  break;
	  case 4: motor1_clockwise();
			  motor2_counterclockwise();
			  break;
	  case 5: printf("Enter power 0-20: ");
			  scanf("%d", &n);
			  if (n < 0) n = 0;
			  if (n > 20) n = 20;
			  wait1 = (uint8_t)n;
			  wait2 = (uint8_t)(20 - n);
			  break;
	} 
	
	if (op < 5)
	{
		while (uart1GetByte() == -1)
		{
		  for (i = 0; i < 10; i++)
		  {
			motor2_off();
			motor1_off();
			for (j = 0; j < wait2; j++) _delay_loop_1(0);
			motor2_on();
			motor1_on();
			for (j = 0; j < wait1; j++) _delay_loop_1(0);
		  }
		}
		motor1_off();
		motor2_off();
	}

  } while (op != 6);

  //turn off LED0 before exit
  PORTE = PINE & ~16;
  
  return 0;

} //end main function


